@@ -1,9 +1,10 @@
 /*
- * Copyright 1999-2004 The Apache Software Foundation
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -174,6 +175,14 @@ public class ServletWebContextTestCase extends ContextBaseTestCase {
         map.clear();
         checkMapSize(map, 0);
 
+        // Test putAll()
+        Map values = new HashMap();
+        values.put(new Integer(1), "One");
+        values.put("2", "Two");
+        map.putAll(values);
+        assertEquals("putAll(1)", "One", map.get("1"));
+        assertEquals("putAll(2)", "Two", map.get("2"));
+        checkMapSize(map, 2);
     }
 
 
@@ -628,6 +637,15 @@ public class ServletWebContextTestCase extends ContextBaseTestCase {
         map.clear();
         checkMapSize(map, 0);
 
+        // Test putAll()
+        Map values = new HashMap();
+        values.put(new Integer(1), "One");
+        values.put("2", "Two");
+        map.putAll(values);
+        assertEquals("putAll(1)", "One", map.get("1"));
+        assertEquals("putAll(2)", "Two", map.get("2"));
+        checkMapSize(map, 2);
+        
     }
 
 
@@ -680,6 +698,15 @@ public class ServletWebContextTestCase extends ContextBaseTestCase {
         map.clear();
         checkMapSize(map, 0);
 
+        // Test putAll()
+        Map values = new HashMap();
+        values.put(new Integer(1), "One");
+        values.put("2", "Two");
+        map.putAll(values);
+        assertEquals("putAll(1)", "One", map.get("1"));
+        assertEquals("putAll(2)", "Two", map.get("2"));
+        checkMapSize(map, 2);
+
     }
 
 
